@@ -19,7 +19,7 @@
 # Free Software Foundation, Inc.,
 # 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
 
-__VERSION__='20.04.0'
+__VERSION__='20.04.1'
 
 import gc
 import gi
@@ -84,7 +84,7 @@ class MainWindow( object ):
 
         self.window.realize()
         self.window.get_window().set_decorations(Gdk.WMDecoration.BORDER)
-        self.window.set_title('')
+        self.window.set_title('Advanced MATE Menu')
         self.window.set_app_paintable(True)
 
         self.window.connect("draw", self.onWindowDraw)
